#!/bin/bash

set -e

up () {
  # Ensure iptables rules exist
  # https://askubuntu.com/questions/1052919/iptables-reload-restart-on-ubuntu/1072948#1072948
  docker network create --ipv6 --subnet "fd01::/80" pew-net || true

  # Exposed on port 32400 in pew-net  
  docker run \
    --detach \
    --name plex \
    --restart unless-stopped \
    --env PUID=1000 \
    --env PGID=1000 \
    --env VERSION=docker \
    --volume /bigdata/k8s-config/plex/config:/config:rw \
    --volume /bigdata/media/movies:/media/movies:ro \
    --volume /bigdata/media/audiobooks:/media/audiobooks:ro \
    --volume /bigdata/media/music:/media/music:ro \
    --volume /media-vtluug:/media/media-vtluug:ro \
    --network pew-net \
    ghcr.io/linuxserver/plex:latest
}

down () {
  docker stop plex || true
  docker rm plex || true
}

logs () {
  docker logs --follow plex
}

$@
